# Mystic BBS (Bulletin Board Software)
----
## What is Mystic BBS?
see [MysticBBS](https://www.mysticbbs.com)

> Mystic BBS was conceived around the year 1995 when the author became frustrated by the lack of customization available with Renegade BBS, and first released to the public in late 1997 during a period when many BBS packages were seeing a decline (or a full stop) in development. Mystic is developed from the ground up with all original source code and is intended to be the spiritual successor to both Telegard and Renegade (two of the packages the author used prior to developing Mystic BBS).

> With the fall of MS-DOS and the decline of the BBS, Mystic continued to push forward by releasing an OS/2 and Windows 32 native version in 1998. Mystic was the first of the non-commerical DOS based BBS packages to make the transition and integrate directly with the Telnet protocol. Mystic also went on to become the first of the MS-DOS based packages to release a native Linux version in 1999, and the first to introduce a standardized platform for DOOR games across all 4 operating systems.

> In the following years after the first MS-DOS release in 1997, Mystic grew to become one of the most widely used BBS packages. Popular amongst many SysOps who took ease of customization and the user experience seriously, it is arguable that Mystic was (or even still is) the most popular BBS software for those who share a common interest in ANSI art and BBS modding.

> In recent years, Mystic has removed its DOS version and its limitations, and has moved on to better integrate with Internet protocols. Mystic now has internal Telnet, RLOGIN, SSH, NNTP, POP3, SMTP, FTP, HTTP and BINKP servers while continuing to focus on and enhance the SysOp and user experience.

----
## About this Docker Container
This Docker Container represents a completed installation of MysticBBS. It is ready to configure and personalise.

To use this container:

1. Docker pull it from my registry. (Actually you can skip this step, but its worth doing it anyway!)

        docker pull registry.leenooks.net/leenooks/mysticbbs:1.12a39-armv7l

2. Create a directory to hold your BBS data. (I use */srv/docker/mystic*).

        mkdir -p /srv/mystic/data

3. Start the container.

        docker run -itd -v /srv/mystic/data:/mystic/data -p 10022:22 -p 10023:23 -p 24554:24554 registry.leenooks.net/leenooks/mysticbbs:1.12a39-armv7l

    Explanation of these parameters:

    | Parameter | Value |
    | :- | :-- |
    | -d | Detached mode: run the container in the background and print the new container ID. |
    | -i | Keep STDIN open even if not attached. (required) |
    | -n | Give your container a specific name. (optional) |
    | -p | Map host ports to container ports. (may be required, otherwise recommended) |
    | -t | Allocate a pseudo-TTY. (required) |
    | -v | Map a path on the host into the container (optional but recommended). |
   
    (There are other useful parameters you can use, like --restart, etc. If you dont pass in a data volume for /mystic/data, docker will create one and preserve it if you start subsequent containers a specific way (beyond the scope of this README - so its recommended you do this in first instance anyway.)

    Remember your container ID *(your number will be different)*. 

        ca219a461376...
       
4. Attach to your container and create your sysop user.

        docker exec -it ca219a461376 ./mystic -l

5. Upgrade your new user to sysop levels

        docker exec -it ca219a461376 ./mystic -cfg

6. You can now start to play. If you externalised your telnet port, then you can telnet in.

If you want to monitor your container, or stop it, attach to the console with:
      
    docker attach ca219a461376

You can also run this in a swarm (I do)!

----
## Info on the Images

### leenooks/mysticbbs:1.12a39-armv7l (Branch: armv7l)
This image is a clean install of Mystic BBS v1.12a39. It is ready for you to configure and personalise.

### leenooks/mysticbbs:1.12a39-armv7l-extras (Branch: armv7l-extras)
This image is based on the above image, with the follow additional games/tools installed. You'll need to refer to the documentation in the docs/ directory (inside the container) for details on how to configure these mods. The docs are named `mod-<NAME OF MOD>-...`

| Category | Name | Description | Notes |
| :- | :- | :- | :- |
| Game | Double Up | Double Up! for Mystic V2.1 by Darryl Perry | No special action required - refer to doc in /mystic/docs for execution. |
| Game | Galactic Dynasty | Galactic Dynasty by Andrew Pamment, a game like Barren Realms Elite | You'll need to copy `/mystic/docs/doors/galacticdynasty` to somewhere on `/mystic/data` so that your game data is preserved between container re-deployments. Modify `start.sh` to suite your needs - refer to doc in /mystic/docs for execution. |
| Game | Master Mind | Master Mind v2 by Dream Master | No special action required - refer to doc in /mystic/docs for execution. |
| Game | Murder Mansion | Murder Mansion v2.0 by Darryl Perry | No special action required - refer to doc in /mystic/docs for execution. |
| Game | Reversi | Reversi v1.0 by Darryl Perry | No special action required - refer to doc in /mystic/docs for execution. |
| Utility | BLAM | BBS List Admin Manager for Mystic v2.0 by Darryl Perry | Refer to doc in /mystic/docs for execution. |
| Utility | IBOL | InterBBS OneLiner 0.4 by Darryl Perry | Refer to doc in /mystic/docs for execution. |
| Utility | ILC| InterBBS Last Caller by xqtr | Refer to doc in /mystic/docs for execution. |
| Utility | MakeNL | Nodelist Management | Refer to the docs in `/usr/share/makenl` |
| Utility | Moon | Display the phase of the Moon by xqtr | No special action required - refer to doc in /mystic/docs for execution. |
| Utility | QRCode | Generate a QR Code by xqtr | No special action required - refer to doc in /mystic/docs for execution. |
| Utility | Sysop Avail | Sysop Availability by Dream Master | No special action required - refer to doc in /mystic/docs for execution. |
| Utility | User Bday | Users Birthdays by Dream Master | No special action required - refer to doc in /mystic/docs for execution. |

**NOTE:** Remember, for anything to persist in the docker container, those files needs to be stored somewhere under  `/mystic/data`

